==> huaweicloudsdkkvs-3.1.139-py2.py3-none-any.whl: huaweicloudsdkkvs/v1/model/table_oper_ids.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class TableOperIds:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'table_name': 'str',
        'kv_oper_ids': 'KvOperIds'
    }

    attribute_map = {
        'table_name': 'table_name',
        'kv_oper_ids': 'kv_oper_ids'
    }

    def __init__(self, table_name=None, kv_oper_ids=None):
        """TableOperIds

        The model defined in huaweicloud sdk

        :param table_name: 表名，仓内唯一。 - 长度：[3, 63] - 取值字符限制：[a-z0-9_-]+
        :type table_name: str
        :param kv_oper_ids: 
        :type kv_oper_ids: :class:`huaweicloudsdkkvs.v1.KvOperIds`
        """
        
        

        self._table_name = None
        self._kv_oper_ids = None
        self.discriminator = None

        self.table_name = table_name
        self.kv_oper_ids = kv_oper_ids

    @property
    def table_name(self):
        """Gets the table_name of this TableOperIds.

        表名，仓内唯一。 - 长度：[3, 63] - 取值字符限制：[a-z0-9_-]+

        :return: The table_name of this TableOperIds.
        :rtype: str
        """
        return self._table_name

    @table_name.setter
    def table_name(self, table_name):
        """Sets the table_name of this TableOperIds.

        表名，仓内唯一。 - 长度：[3, 63] - 取值字符限制：[a-z0-9_-]+

        :param table_name: The table_name of this TableOperIds.
        :type table_name: str
        """
        self._table_name = table_name

    @property
    def kv_oper_ids(self):
        """Gets the kv_oper_ids of this TableOperIds.

        :return: The kv_oper_ids of this TableOperIds.
        :rtype: :class:`huaweicloudsdkkvs.v1.KvOperIds`
        """
        return self._kv_oper_ids

    @kv_oper_ids.setter
    def kv_oper_ids(self, kv_oper_ids):
        """Sets the kv_oper_ids of this TableOperIds.

        :param kv_oper_ids: The kv_oper_ids of this TableOperIds.
        :type kv_oper_ids: :class:`huaweicloudsdkkvs.v1.KvOperIds`
        """
        self._kv_oper_ids = kv_oper_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TableOperIds):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkkvs-3.1.156-py2.py3-none-any.whl: huaweicloudsdkkvs/v1/model/table_oper_ids.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class TableOperIds:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'table_name': 'str',
        'kv_oper_ids': 'KvOperIds'
    }

    attribute_map = {
        'table_name': 'table_name',
        'kv_oper_ids': 'kv_oper_ids'
    }

    def __init__(self, table_name=None, kv_oper_ids=None):
        r"""TableOperIds

        The model defined in huaweicloud sdk

        :param table_name: 表名，仓内唯一。 - 长度：[3, 63] - 取值字符限制：[a-z0-9_-]+
        :type table_name: str
        :param kv_oper_ids: 
        :type kv_oper_ids: :class:`huaweicloudsdkkvs.v1.KvOperIds`
        """
        
        

        self._table_name = None
        self._kv_oper_ids = None
        self.discriminator = None

        self.table_name = table_name
        self.kv_oper_ids = kv_oper_ids

    @property
    def table_name(self):
        r"""Gets the table_name of this TableOperIds.

        表名，仓内唯一。 - 长度：[3, 63] - 取值字符限制：[a-z0-9_-]+

        :return: The table_name of this TableOperIds.
        :rtype: str
        """
        return self._table_name

    @table_name.setter
    def table_name(self, table_name):
        r"""Sets the table_name of this TableOperIds.

        表名，仓内唯一。 - 长度：[3, 63] - 取值字符限制：[a-z0-9_-]+

        :param table_name: The table_name of this TableOperIds.
        :type table_name: str
        """
        self._table_name = table_name

    @property
    def kv_oper_ids(self):
        r"""Gets the kv_oper_ids of this TableOperIds.

        :return: The kv_oper_ids of this TableOperIds.
        :rtype: :class:`huaweicloudsdkkvs.v1.KvOperIds`
        """
        return self._kv_oper_ids

    @kv_oper_ids.setter
    def kv_oper_ids(self, kv_oper_ids):
        r"""Sets the kv_oper_ids of this TableOperIds.

        :param kv_oper_ids: The kv_oper_ids of this TableOperIds.
        :type kv_oper_ids: :class:`huaweicloudsdkkvs.v1.KvOperIds`
        """
        self._kv_oper_ids = kv_oper_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TableOperIds):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
